@@ -8,7 +8,7 @@ use Dist::Zilla::MintingProfile::Author::Plicease;
 use JSON qw( to_json );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -61,6 +61,38 @@ sub gather_files
   $self->gather_file_changes($arg);
   $self->gather_files_tests($arg);
   $self->gather_file_gitignore($arg);
+  $self->gather_file_travis_yml($arg);
+}
+
+sub gather_file_travis_yml
+{
+  my($self, $arg) = @_;
+
+  my $file = Dist::Zilla::File::InMemory->new({
+    name    => '.travis.yml',
+    content => join("\n", q{language: perl},
+                          q{},
+                          q{#install:},
+                          q{#  - cpanm -n Foo::Bar},
+                          q{},
+                          q{perl:},
+                          (map { "  - \"5.$_\""} qw( 10 12 14 16 18 )),
+                          q{},
+                          q{#before_script:},
+                          q{},
+                          q{script: HARNESS_IS_VERBOSE=1 prove -lv t xt},
+                          q{},
+                          q{#after_script:},
+                          q{},
+                          q{branches:},
+                          q{  only:},
+                          q{    - master},
+                          q{},
+    ),
+  });
+
+  $self->add_file($file);
+
 }
 
 sub gather_file_dist_ini
@@ -105,10 +137,10 @@ sub gather_file_dist_ini
              .  ";Foo::Bar = 0\n"
              .  "\n";
     
-    $content .= ";[UploadToCPAN]\n"
+    $content .= ";[Author::Plicease::UploadToCPAN]\n"
              .  "\n";
              
-    $content .= ";[UploadToMatrix]\n"
+    $content .= ";[Author::Plicease::UploadToMatrix]\n"
              .  "\n";
 
     $content;
@@ -266,7 +298,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 DESCRIPTION
 
